'use strict';

// src/error/index.ts
var Level = /* @__PURE__ */ ((Level2) => {
  Level2["ERROR"] = "ERROR";
  Level2["WARNING"] = "WARNING";
  Level2["INFO"] = "INFO";
  Level2["DEBUG"] = "DEBUG";
  return Level2;
})(Level || {});
var Domain = /* @__PURE__ */ ((Domain2) => {
  Domain2["TOOL"] = "TOOL";
  Domain2["AGENT"] = "AGENT";
  Domain2["MCP"] = "MCP";
  Domain2["UNKNOWN"] = "UNKNOWN";
  return Domain2;
})(Domain || {});
var ErrorCategory = /* @__PURE__ */ ((ErrorCategory2) => {
  ErrorCategory2["UNKNOWN"] = "UNKNOWN";
  ErrorCategory2["USER"] = "USER";
  ErrorCategory2["SYSTEM"] = "SYSTEM";
  return ErrorCategory2;
})(ErrorCategory || {});
var MastraError = class extends Error {
  id;
  domain;
  category;
  originalError;
  details = {};
  constructor(errorDefinition, originalError) {
    const message = errorDefinition.text;
    super(message, originalError);
    this.id = errorDefinition.id;
    this.domain = errorDefinition.domain;
    this.category = errorDefinition.category;
    this.originalError = originalError;
    this.details = errorDefinition.details ?? {};
    Object.setPrototypeOf(this, new.target.prototype);
  }
  /**
   * Returns a structured representation of the error, useful for logging or API responses.
   */
  toJSONDetails() {
    return {
      message: this.message,
      domain: this.domain,
      category: this.category,
      stack: this.stack,
      originalError: this.originalError,
      details: this.details
    };
  }
  toJSON() {
    return {
      message: this.message,
      details: this.toJSONDetails(),
      code: this.id
    };
  }
};
var error = new MastraError({
  id: "BASE_TEST_001",
  text: "This is a base test error",
  domain: "AGENT" /* AGENT */,
  category: "UNKNOWN" /* UNKNOWN */,
  details: {
    tset: "lalal"
  }
});
console.log(error.toJSON());

exports.Domain = Domain;
exports.ErrorCategory = ErrorCategory;
exports.Level = Level;
exports.MastraError = MastraError;
